#' Seed geographical dictionary in English
#'
#' @name data_dictionary_newsmap_en
#' @docType data
#' @author Kohei Watanabe \email{watanabe.kohei@gmail.com}
#' @keywords data
NULL

#' Seed geographical dictionary in Japanese
#'
#' @name data_dictionary_newsmap_ja
#' @docType data
#' @author Kohei Watanabe \email{watanabe.kohei@gmail.com}
#' @keywords data
NULL

#' Seed geographical dictionary in German
#'
#' @name data_dictionary_newsmap_de
#' @docType data
#' @author Stefan Müller \email{mullers@tcd.ie}
#' @keywords data
NULL

#' Seed geographical dictionary in French
#'
#' @name data_dictionary_newsmap_fr
#' @docType data
#' @author Claude Grasland \email{claude.grasland@parisgeo.cnrs.fr}
#' @keywords data
NULL

#' Seed geographical dictionary in Spanish
#'
#' @name data_dictionary_newsmap_es
#' @docType data
#' @author Dani Madrid-Morales \email{dani.madrid@my.cityu.edu.hk}
#' @keywords data
NULL

#' Seed geographical dictionary in Russian
#'
#' @name data_dictionary_newsmap_ru
#' @docType data
#' @author Katerina Tertytchnaya \email{katerina.tertytchnaya@gmail.com}
#' @keywords data
NULL

#' Seed geographical dictionary in Chinese (simplified)
#'
#' @name data_dictionary_newsmap_zh_cn
#' @docType data
#' @author Ke Cheng \email{kecheng.ac@gmail.com}
#' @keywords data
NULL

#' Seed geographical dictionary in Chinese (traditional)
#'
#' @name data_dictionary_newsmap_zh_tw
#' @docType data
#' @author Chung-hong Chan \email{chainsawtiney@gmail.com}
#' @keywords data
NULL
